CREATE OR REPLACE PROCEDURE ATUALIZA_DELIVERY_SERVPLANO(
   P_CDCIA       IN COMPANHIA.CDCIA%TYPE,
   P_CDFILIAL    IN FILIAL.CDFILIAL%TYPE,
   P_NRAPURACFAT IN NOTAFISCAL.NRAPURACFAT%TYPE,
   P_NRPEDIDO IN VARCHAR2)

AS

   V_NRDELIVERY  DELIVERY.NRDELIVERY%TYPE;

   V_QUANTIDADE      ITEMPRODUTO.QTITEMPROD%TYPE;
   V_VRPESOBRUTO     ITEMPRODUTO.QTITEMPROD%TYPE;
   V_VRLIQUIDO       ITEMPRODUTO.QTITEMPROD%TYPE;
   V_NRPEDIDOFAC VARCHAR2(20);


   CURSOR C_TRAB_APURAC IS SELECT TA.CDCIAAP, TA.NRDELIVERYAP, TA.NRVOOAP,
                                  TA.CDTRECHOAP, TA.DTHRPLAVOOPVAP, PR.CDPRODUTO,
                                  TA.CDFILIALAP, TA.NRLANCTONFAP, TA.CDFILISERVAP
                           FROM TRAB_APURAC TA, PRODUTO PR
                           WHERE TA.CDCIAAP       = P_CDCIA       AND
                                 TA.CDFILIALAP    = P_CDFILIAL    AND
                                 TA.NRAPURACFATAP = P_NRAPURACFAT AND
                                 TA.CDSERVICOAP   = PR.CDARVPROD  AND
                                 TA.CDFILISERVAP IS NOT NULL
                           ORDER BY NRDELIVERYAP;

BEGIN

-- =============================================================================
-- ATUALIZACAO DA TABELA DE SERVPLANO E DELIVERY
-- =============================================================================

   V_NRDELIVERY := 0;

   FOR CURS_TRAB IN C_TRAB_APURAC LOOP

      IF V_NRDELIVERY <> CURS_TRAB.NRDELIVERYAP THEN
         UPDATE DELIVERY
         SET    IDSITDEL = '2'
         WHERE
            NRDELIVERY = CURS_TRAB.NRDELIVERYAP AND
            CDFILIAL   = CURS_TRAB.CDFILISERVAP;
      END IF;

      UPDATE SERVPLANO
      SET NRLANCTONF = CURS_TRAB.NRLANCTONFAP,
          CDFILIALNF = CURS_TRAB.CDFILIALAP
      WHERE CDFILIAL     = CURS_TRAB.CDFILISERVAP   AND
            CDCIA        = CURS_TRAB.CDCIAAP        AND
            NRDELIVERY   = CURS_TRAB.NRDELIVERYAP   AND
            NRVOO        = CURS_TRAB.NRVOOAP        AND
            CDTRECHO     = CURS_TRAB.CDTRECHOAP     AND
            DTHRPLAVOOPV = CURS_TRAB.DTHRPLAVOOPVAP AND
            CDSERVICO    = CURS_TRAB.CDPRODUTO      AND
            NRLANCTONF IS NULL;

      SELECT SUM(P.QTITEMPROD) AS QTITEMPROD,
             SUM(P.QTITEMPROD * NVL(PR.VRPESOUNID, 0)) AS VRPESOBRUTO
      INTO V_QUANTIDADE, V_VRPESOBRUTO
      FROM ITEMPRODUTO P,  PRODUTO PR
      WHERE P.CDFILIAL      = CURS_TRAB.CDFILIALAP     AND
            P.NRLANCTONF    = CURS_TRAB.NRLANCTONFAP   AND
            P.CDPRODEMIS    = PR.CDARVPROD             AND
            NOT EXISTS (SELECT NRSEQITPROD
                        FROM ITEMPROIMPOS I
                        WHERE I.CDFILIAL    =  CURS_TRAB.CDFILIALAP   AND
                              I.NRLANCTONF  =  CURS_TRAB.NRLANCTONFAP AND
                              I.CDIMPOSTO   = '31'                    AND
                              I.NRSEQITPROD = P.NRSEQITPROD);

      V_VRLIQUIDO := V_VRPESOBRUTO * 97/100;

      UPDATE NOTAFISCAL
      SET IDPGTOFRETE  = '1',
          DSQTDEVOLU   = SUBSTR(TO_CHAR(ROUND(V_QUANTIDADE,0)),1,6),
          DSESPECVOLU  = 'VOLUME',
          VRPBRUTOVOLU = TO_CHAR(ROUND(V_VRPESOBRUTO,2)),
          VRPLIQUVOLU  = V_VRLIQUIDO
      WHERE CDFILIAL   = CURS_TRAB.CDFILIALAP AND
            NRLANCTONF = CURS_TRAB.NRLANCTONFAP;


      V_NRDELIVERY := CURS_TRAB.NRDELIVERYAP;
   END LOOP;

   DELETE FROM TRAB_APURAC
   WHERE CDCIAAP       = P_CDCIA    AND
         CDFILIALAP    = P_CDFILIAL AND
         NRAPURACFATAP = P_NRAPURACFAT;

   UPDATE CTRLAPURFAT
   SET IDAPURACOK = 'S'
   WHERE CDFILIAL    = P_CDFILIAL AND
         NRAPURACFAT = P_NRAPURACFAT;
   
   /* Atualiza o nmero do pedido nos itens das notas fiscais geradas */
   FOR C_NOTAS IN
   (SELECT CDFILIAL, NRLANCTONF
      FROM NOTAFISCAL
     WHERE CDFILIAL = P_CDFILIAL AND
           NRAPURACFAT = P_NRAPURACFAT
   ) LOOP
      UPDATE ITEMPRODUTO
         SET NRPEDPROD = P_NRPEDIDO
       WHERE CDFILIAL = C_NOTAS.CDFILIAL
         AND NRLANCTONF = C_NOTAS.NRLANCTONF;
   END LOOP;

   /* Atualiza o nmero do pedido utilizado na filial e na companhia */
   UPDATE PEDIDOFAC
      SET CDPEDIDO = P_NRPEDIDO
    WHERE CDFILIAL = P_CDFILIAL
      AND CDCIA = P_CDCIA;
   
   IF SQL%ROWCOUNT = 0 THEN
      NOVO_CODIGO_SC('PEDIDOFAC',V_NRPEDIDOFAC);
      
      INSERT INTO PEDIDOFAC
      (NRPEDIDOFAC, CDFILIAL, CDCIA, CDPEDIDO)
      VALUES
      (TO_NUMBER(V_NRPEDIDOFAC), P_CDFILIAL, P_CDCIA, P_NRPEDIDO);
      
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('ATUALIZA_DELIVERY_SERVPLANO','5.85.xxx'); END;
/